
2024 JAN 15

*   Select-able query implementations via `DistinctValuesQuery` enum.
*   Initial implementation of FS_56_43_05_79 search in different collections.
*   Introduce `PluginType.ConfiguratorPlugin` (e.g. to configure some values on GUI page).
*   Sort enum items (simplifies looking through and comparing the output).
*   Test infra: initial implementation of FS_62_25_92_06 generated config.
